IntExt extension

Extension on int providing date formatting methods for milliseconds since epoch.

Treats the integer as milliseconds since epoch and provides convenient getters to format it in various date/time formats. Returns '-' for values <= 0.

on

Properties

asDDMMM → String

Available on int, provided by the IntExt extension

Formats as "dd-MMM".
no setter
asDDMMMYHHMMSS → String

Available on int, provided by the IntExt extension

Formats as "dd-MMM-y HH:mm:ss".
no setter
asDDMMMYHHMMSSAAA → String

Available on int, provided by the IntExt extension

Formats as "dd-MMM-y HH:mm:ss:SSS" with milliseconds.
no setter
asDDMMYYYY → String

Available on int, provided by the IntExt extension

Formats as "dd-MMM-y".
no setter
asDDMMYYYYHHMMA → String

Available on int, provided by the IntExt extension

Formats as "dd-MMM-y h:mm a".
no setter
asEEE → String

Available on int, provided by the IntExt extension

Formats as "EEE" (day of week).
no setter
asEEEhhmma → String

Available on int, provided by the IntExt extension

Formats as "EEE hh:mm a" (day and time).
no setter
asHH12MMSSA → String

Available on int, provided by the IntExt extension

Formats as "hh:mm:ss a" (12-hour with AM/PM).
no setter
asHHMMA → String

Available on int, provided by the IntExt extension

Formats as "hh:mm a" (12-hour with AM/PM).
no setter
asHHMMSS → String

Available on int, provided by the IntExt extension

Formats as "HH:mm:ss" (24-hour).
no setter
asYYYYMM → String

Available on int, provided by the IntExt extension

Formats as "y-MM".
no setter
asYYYYMMM → String

Available on int, provided by the IntExt extension

Formats as "y-MMM".
no setter
yyyymmddhhmmssForFileName → String

Available on int, provided by the IntExt extension

Formats as "y-MM-dd-HH-mm-ss" (suitable for file names).
no setter