ColorUtil class

Utility class for color-related operations.

Provides helper methods for creating and manipulating colors.

Constructors

ColorUtil()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

colorFromHex(String hexString) → Color
Creates a Color from a hexadecimal string.