Result class

Represents a simple result with success status and message.

This is a lightweight alternative to ProcessResult when you don't need to carry a result object, only a success flag and message.

Constructors

Result(bool success, String msg)
Creates a result with the given success status and msg.
Result.failureMsg(String msg)
Creates a failure result with the given msg.
Result.successMsg(String msg)
Creates a success result with the given msg.

Properties

hashCode → int
The hash code for this object.
no setterinherited
msg ↔ String
Message describing the result.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
success ↔ bool
Whether the operation succeeded.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited