NextBackStackController class

Constructors

NextBackStackController()

Properties

hashCode → int
The hash code for this object.
no setterinherited
headerController ↔ WidgetHolderController
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state ↔ NextBackStackState
getter/setter pair

Methods

back() → void
backButton() → Widget
headerWidget() → Widget
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setAsBase(Widget widget, {Widget? header, VoidCallback? onBack}) → void
show(Widget widget, {Widget? header, VoidCallback? onBack}) → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited