IsolateWorker<T extends IsolateCommand<R>, R> class

A generic worker class that processes jobs in a separate isolate

Constructors

IsolateWorker()
Creates an IsolateWorker with the given action callback

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose() Future<void>
Disposes the isolate and cleans up resources
initialize() Future<void>
Initializes the isolate and sets up communication
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sendJob(T cmd) Future<R>
Sends a job to the isolate and returns a Future with the result
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited